==> vlc-debug-1:3.0.23-3-x86_64.pkg.tar.zst: usr/src/debug/vlc/vlc-b71bd03233a6a9392c906a22345041a9447bc49a/modules/gui/qt/widgets_qmlassets.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 6.10.1
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#ifdef _MSC_VER
// disable informational message "function ... selected for automatic inline expansion"
#pragma warning (disable: 4711)
#endif

static const unsigned char qt_resource_data[] = {
  // qmldir
  0x0,0x0,0x3,0xa5,
  0x28,
  0xb5,0x2f,0xfd,0x60,0x24,0xc,0xdd,0x1c,0x0,0xd6,0xe0,0x5a,0x1d,0x40,0x75,0xe,
  0x3f,0x66,0xe7,0xa9,0x24,0xd9,0x48,0xee,0x91,0x76,0xc3,0xfb,0x9b,0x99,0xb,0x77,
  0xfb,0x8e,0xe0,0x15,0x18,0x8a,0x8a,0x46,0x4,0x2e,0x57,0x0,0x52,0x0,0x50,0x0,
  0x20,0xff,0x74,0xd4,0x94,0xd5,0x8f,0x55,0x6e,0x22,0x5a,0x6e,0x58,0x6a,0xb8,0xf5,
  0x2f,0x94,0xbc,0x1f,0x99,0x36,0x6e,0x80,0xdc,0x4b,0x6e,0x89,0x42,0x8b,0x27,0x33,
  0x46,0x8e,0x96,0xfa,0x4,0x84,0xeb,0xd9,0x91,0x70,0xff,0xbf,0x88,0x5b,0x9f,0x1d,
  0x0,0x82,0x0,0x41,0x50,0x8,0xfc,0x27,0xb1,0x49,0xe1,0x3,0x30,0x18,0xc,0xd6,
  0xe2,0xc,0x9e,0x33,0x30,0x4,0x3c,0x33,0xe9,0x17,0xc0,0x7d,0x56,0x4d,0x31,0x2,
  0xe9,0x71,0x9,0xe4,0xbe,0xd6,0x56,0x2e,0x2b,0x8b,0xcf,0x1d,0x52,0x6f,0xc6,0xb3,
  0x32,0x40,0x7f,0x59,0x9e,0xd4,0x4b,0x53,0x5f,0x34,0xc6,0xeb,0x93,0x48,0x8f,0x95,
  0xdf,0xa8,0x9e,0xd3,0xfd,0x61,0xfe,0x94,0xee,0x35,0xc4,0x73,0x1b,0x23,0xe3,0x42,
  0x47,0x44,0x2e,0xb4,0x38,0x52,0xb9,0xaf,0x9e,0x6e,0xac,0x98,0x9c,0xd2,0x4a,0x8d,
  0x5,0x31,0xb5,0x7c,0xb4,0x94,0xf5,0x91,0x69,0x46,0xbf,0x23,0x15,0xeb,0x63,0xaf,
  0xa2,0xf1,0x6b,0xaf,0x36,0xc,0x23,0xa6,0x1b,0xf8,0xac,0x97,0x3f,0xb7,0xf4,0xde,
  0x4d,0xf7,0xd3,0x91,0x86,0x39,0xe6,0xb6,0xb3,0xa9,0xff,0x1d,0xfe,0x93,0xce,0xa5,
  0x57,0xdd,0xb2,0xf1,0xeb,0xa,0x8,0x77,0xb2,0x2d,0xe5,0x52,0x58,0x69,0x7,0x23,
  0x8f,0xc7,0xb9,0xaf,0x4f,0xbd,0x29,0x3b,0x2d,0xa1,0xb6,0x84,0x38,0x2e,0xb2,0xf6,
  0x74,0x43,0xcd,0xf4,0xfb,0x30,0x93,0x9e,0xd,0x93,0xd1,0x95,0xdc,0x77,0xfa,0xc8,
  0xa,0x2d,0xf4,0xed,0xb6,0xb0,0x46,0x86,0x34,0x6f,0xa3,0x74,0xe8,0x41,0xc7,0xe2,
  0xe3,0x49,0x9b,0xdb,0xbb,0x62,0x7c,0x96,0x95,0x96,0xad,0xd,0x1b,0xe7,0x46,0xef,
  0x5a,0x32,0x46,0xd,0x2f,0xea,0xfb,0xf5,0x2e,0x6f,0x45,0x4b,0x54,0xac,0xd,0x73,
  0xa9,0xd7,0x57,0x5f,0x6a,0x79,0x96,0x99,0x4c,0xc2,0x39,0xdc,0x45,0xcb,0x77,0xed,
  0x97,0x7e,0xc5,0xfa,0xac,0xad,0x8b,0x8f,0xd2,0xd9,0xf4,0x2,0xc2,0xb6,0xa9,0xa,
  0xc7,0xd6,0x6b,0xd8,0x8f,0xd,0xb,0x81,0x2c,0xa8,0xb1,0xca,0x8,0x8d,0x8c,0x94,
  0x14,0x24,0x49,0x6b,0x31,0xc,0x21,0x6a,0x52,0x5d,0x79,0x31,0x8,0xc9,0x42,0xcc,
  0x29,0x66,0x66,0x4e,0x93,0xc,0x73,0x8f,0xd0,0x2,0x1c,0xf1,0xbd,0xbc,0x70,0xe3,
  0xe,0x15,0x9b,0x9,0x74,0xc0,0xaf,0xe3,0x2b,0xbf,0xfd,0x2a,0x3b,0x5e,0x1d,0x90,
  0x97,0x61,0x25,0xe8,0x36,0x32,0x78,0x13,0x70,0x76,0x90,0x28,0x25,0x4b,0xba,0x34,
  0x12,0x48,0xed,0x22,0x13,0xb,0xca,0xf0,0x2e,0x0,0xb2,0x98,0xac,0xea,0x4d,0xcc,
  0xd3,0x43,0xf7,0x7d,0xf,0x1f,0x31,0x84,0x28,0xd8,0x2f,0x40,0xfd,0x1c,0x15,0xc5,
  0x2c,0xc2,0xef,0xba,0xbb,0xa3,0x6,0x30,0x9d,0x26,0x12,0x5d,0x30,0xab,0xe0,0x9a,
  0x14,0x16,0x62,0x1,0x23,0xf3,0x4c,0x8f,0x8e,0x9c,0x28,0x78,0x8d,0x27,0xd2,0xaf,
  0x13,0xcc,0x50,0x7b,0x72,0x25,0xb0,0xa1,0x89,0xa5,0x63,0xd1,0x81,0x8e,0xd0,0xe1,
  0xdc,0x88,0x72,0xfa,0xb6,0x73,0x1f,0x52,0x7d,0x2f,0x92,0x33,0x9,0x2b,0x79,0x7b,
  0x85,0x4e,0x26,0x9f,0xa1,0xb2,0x2f,0xd8,0x5b,0x50,0x27,0x2e,0x36,0x13,0xf5,0x58,
  0x38,0xac,0xed,0x7d,0x21,0xa7,0x99,0x79,0xa3,0xa0,0x14,0x2a,0x2d,0x7d,0x35,0xe3,
  0x28,0x60,0xb7,0x63,0xbe,0x41,0x7,0xf1,0x13,0x20,0x70,0xa1,0xff,0x34,0xfe,0x33,
  0x8d,0xf0,0x8a,0x7e,0xa1,0x18,0xb5,0x2b,0x4f,0xf1,0x34,0x8f,0x37,0xfa,0x20,0x44,
  0xae,0xc5,0xd7,0x8d,0x6d,0x8c,0x31,0x19,0x33,0xfb,0x45,0xb3,0x5f,0xe4,0x9,0xd1,
  0x30,0xc3,0x56,0x73,0xf1,0x98,0x99,0xe3,0xe9,0xf,0x6e,0xf2,0xa6,0x19,0xca,0x39,
  0x18,0xcf,0x31,0x83,0x0,0x6d,0xfa,0xa6,0x9,0xe,0xe6,0x46,0x58,0xce,0x98,0x1e,
  0xc1,0xd3,0x91,0xea,0xc4,0x84,0x4b,0x59,0xc0,0xd4,0xac,0x22,0x26,0x5c,0x7,0x10,
  0x3e,0xd1,0xf0,0xa6,0x5e,0xbf,0x33,0xa0,0x11,0xd,0x7f,0x6a,0x9,0x19,0xac,0xa5,
  0x5e,0x28,0x95,0xe8,0x10,0xfe,0x90,0xa,0x67,0x2,0x1d,0x9f,0xb1,0x24,0x50,0x20,
  0xb2,0xed,0x87,0x23,0xaf,0x94,0xa3,0xae,0x52,0xd4,0x68,0xd,0xaf,0x2c,0x7b,0x2f,
  0x94,0x9b,0x7,0x6b,0x84,0x62,0xf9,0x6a,0x67,0xb7,0x99,0x6f,0x90,0x96,0x5,0x69,
  0x81,0xe0,0xf3,0x8b,0x18,0xe7,0x18,0xc7,0xcd,0x8b,0x7e,0xd0,0xc2,0xa,0x43,0xe9,
  0x58,0xf1,0x99,0x19,0xdb,0x55,0x89,0xcc,0xb5,0x92,0x85,0xb4,0x18,0xe5,0xce,0x37,
  0xe1,0xc0,0x58,0x86,0xf2,0x98,0xd3,0x85,0x64,0xc,0x96,0xfd,0x40,0x1c,0x20,0x41,
  0x93,0xec,0xc6,0xb1,0xa0,0x6d,0x9,0x85,0x25,0x71,0xe0,0xca,0x8a,0x65,0x5b,0x44,
  0xaa,0x5e,0xb,0x4a,0x4c,0xa7,0xbc,0xb5,0x85,0xe4,0xcf,0x2,0xa4,0x1d,0x5,0x9a,
  0x40,0x6c,0x85,0xdb,0xf2,0x6d,0x5,0x35,0xc3,0x35,0x7e,0xc4,0x2,0xdc,0x92,0x59,
  0xc6,0x60,0x9a,0xa8,0x84,0xdc,0x53,0xf8,0x53,0x41,0xd8,0xb1,0xe2,0x33,0xf9,0xac,
  0xfb,0xa2,0xd2,0x9c,0xb7,0x6f,0x52,0x6a,0x1,0x4d,0xaf,0x79,0x19,0x53,0x4e,0x22,
  0xe6,0xc,0x25,0x58,0xbe,0xb,0xf4,0xbd,0x21,0xe3,0xbc,0x9e,0xae,0x7f,0xb8,0x91,
  0x7d,0xd5,0x5b,0xbb,0x12,0xec,0x90,0xc6,0x92,0x22,0x6f,0x69,0xa8,0x4f,0x21,0x76,
  0x2e,0x9b,0x1,0x1a,0xba,0xcb,0x13,0x82,0xf4,0x33,0xc1,0x6a,0x9e,0x78,0x2c,0x38,
  0x67,0x50,0xc0,0x8,0x6a,0x36,0xd9,0x99,0x41,0x8c,0x5f,0x85,0x3,0x71,0xfa,0x1f,
  0x67,0xf,0x60,0x55,
  
};

static const unsigned char qt_resource_name[] = {
  // qt
  0x0,0x2,
  0x0,0x0,0x7,0x84,
  0x0,0x71,
  0x0,0x74,
    // qml
  0x0,0x3,
  0x0,0x0,0x78,0x3c,
  0x0,0x71,
  0x0,0x6d,0x0,0x6c,
    // VLC
  0x0,0x3,
  0x0,0x0,0x5b,0x3,
  0x0,0x56,
  0x0,0x4c,0x0,0x43,
    // Widgets
  0x0,0x7,
  0xd,0xfa,0xdc,0x13,
  0x0,0x57,
  0x0,0x69,0x0,0x64,0x0,0x67,0x0,0x65,0x0,0x74,0x0,0x73,
    // qmldir
  0x0,0x6,
  0x7,0x84,0x2b,0x2,
  0x0,0x71,
  0x0,0x6d,0x0,0x6c,0x0,0x64,0x0,0x69,0x0,0x72,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x1,0x9b,0xd5,0xdd,0x70,0xd0,
  // :/qt
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x1,0x9b,0xd5,0xdd,0x70,0xd0,
  // :/qt/qml
  0x0,0x0,0x0,0xa,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x3,
0x0,0x0,0x1,0x9b,0xd5,0xdd,0x70,0xd0,
  // :/qt/qml/VLC
  0x0,0x0,0x0,0x16,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x4,
0x0,0x0,0x1,0x9b,0xd5,0xdd,0x70,0xd0,
  // :/qt/qml/VLC/Widgets
  0x0,0x0,0x0,0x22,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x5,
0x0,0x0,0x1,0x9b,0xd5,0xdd,0x70,0xd0,
  // :/qt/qml/VLC/Widgets/qmldir
  0x0,0x0,0x0,0x36,0x0,0x4,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x9b,0xd5,0xdd,0x70,0xd0,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#if defined(QT_INLINE_NAMESPACE)
inline namespace QT_NAMESPACE {
#elif defined(QT_NAMESPACE)
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#if defined(__ELF__) || defined(__APPLE__)
static inline unsigned char qResourceFeatureZstd()
{
    extern const unsigned char qt_resourceFeatureZstd;
    return qt_resourceFeatureZstd;
}
#else
unsigned char qResourceFeatureZstd();
#endif

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_widgets_assets)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_widgets_assets)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_widgets_assets)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_widgets_assets)()
{
    int version = 3;
    version += QT_RCC_PREPEND_NAMESPACE(qResourceFeatureZstd());
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

#ifdef __clang__
#   pragma clang diagnostic push
#   pragma clang diagnostic ignored "-Wexit-time-destructors"
#endif

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_widgets_assets)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_widgets_assets)(); }
   } dummy;
}

#ifdef __clang__
#   pragma clang diagnostic pop
#endif

==> vlc-debug-1:3.0.23-4-x86_64.pkg.tar.zst: usr/src/debug/vlc/vlc-b71bd03233a6a9392c906a22345041a9447bc49a/modules/gui/qt/widgets_qmlassets.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 6.10.2
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#ifdef _MSC_VER
// disable informational message "function ... selected for automatic inline expansion"
#pragma warning (disable: 4711)
#endif

static const unsigned char qt_resource_data[] = {
  // qmldir
  0x0,0x0,0x3,0xa5,
  0x28,
  0xb5,0x2f,0xfd,0x60,0x24,0xc,0xdd,0x1c,0x0,0xd6,0xe0,0x5a,0x1d,0x40,0x75,0xe,
  0x3f,0x66,0xe7,0xa9,0x24,0xd9,0x48,0xee,0x91,0x76,0xc3,0xfb,0x9b,0x99,0xb,0x77,
  0xfb,0x8e,0xe0,0x15,0x18,0x8a,0x8a,0x46,0x4,0x2e,0x57,0x0,0x52,0x0,0x50,0x0,
  0x20,0xff,0x74,0xd4,0x94,0xd5,0x8f,0x55,0x6e,0x22,0x5a,0x6e,0x58,0x6a,0xb8,0xf5,
  0x2f,0x94,0xbc,0x1f,0x99,0x36,0x6e,0x80,0xdc,0x4b,0x6e,0x89,0x42,0x8b,0x27,0x33,
  0x46,0x8e,0x96,0xfa,0x4,0x84,0xeb,0xd9,0x91,0x70,0xff,0xbf,0x88,0x5b,0x9f,0x1d,
  0x0,0x82,0x0,0x41,0x50,0x8,0xfc,0x27,0xb1,0x49,0xe1,0x3,0x30,0x18,0xc,0xd6,
  0xe2,0xc,0x9e,0x33,0x30,0x4,0x3c,0x33,0xe9,0x17,0xc0,0x7d,0x56,0x4d,0x31,0x2,
  0xe9,0x71,0x9,0xe4,0xbe,0xd6,0x56,0x2e,0x2b,0x8b,0xcf,0x1d,0x52,0x6f,0xc6,0xb3,
  0x32,0x40,0x7f,0x59,0x9e,0xd4,0x4b,0x53,0x5f,0x34,0xc6,0xeb,0x93,0x48,0x8f,0x95,
  0xdf,0xa8,0x9e,0xd3,0xfd,0x61,0xfe,0x94,0xee,0x35,0xc4,0x73,0x1b,0x23,0xe3,0x42,
  0x47,0x44,0x2e,0xb4,0x38,0x52,0xb9,0xaf,0x9e,0x6e,0xac,0x98,0x9c,0xd2,0x4a,0x8d,
  0x5,0x31,0xb5,0x7c,0xb4,0x94,0xf5,0x91,0x69,0x46,0xbf,0x23,0x15,0xeb,0x63,0xaf,
  0xa2,0xf1,0x6b,0xaf,0x36,0xc,0x23,0xa6,0x1b,0xf8,0xac,0x97,0x3f,0xb7,0xf4,0xde,
  0x4d,0xf7,0xd3,0x91,0x86,0x39,0xe6,0xb6,0xb3,0xa9,0xff,0x1d,0xfe,0x93,0xce,0xa5,
  0x57,0xdd,0xb2,0xf1,0xeb,0xa,0x8,0x77,0xb2,0x2d,0xe5,0x52,0x58,0x69,0x7,0x23,
  0x8f,0xc7,0xb9,0xaf,0x4f,0xbd,0x29,0x3b,0x2d,0xa1,0xb6,0x84,0x38,0x2e,0xb2,0xf6,
  0x74,0x43,0xcd,0xf4,0xfb,0x30,0x93,0x9e,0xd,0x93,0xd1,0x95,0xdc,0x77,0xfa,0xc8,
  0xa,0x2d,0xf4,0xed,0xb6,0xb0,0x46,0x86,0x34,0x6f,0xa3,0x74,0xe8,0x41,0xc7,0xe2,
  0xe3,0x49,0x9b,0xdb,0xbb,0x62,0x7c,0x96,0x95,0x96,0xad,0xd,0x1b,0xe7,0x46,0xef,
  0x5a,0x32,0x46,0xd,0x2f,0xea,0xfb,0xf5,0x2e,0x6f,0x45,0x4b,0x54,0xac,0xd,0x73,
  0xa9,0xd7,0x57,0x5f,0x6a,0x79,0x96,0x99,0x4c,0xc2,0x39,0xdc,0x45,0xcb,0x77,0xed,
  0x97,0x7e,0xc5,0xfa,0xac,0xad,0x8b,0x8f,0xd2,0xd9,0xf4,0x2,0xc2,0xb6,0xa9,0xa,
  0xc7,0xd6,0x6b,0xd8,0x8f,0xd,0xb,0x81,0x2c,0xa8,0xb1,0xca,0x8,0x8d,0x8c,0x94,
  0x14,0x24,0x49,0x6b,0x31,0xc,0x21,0x6a,0x52,0x5d,0x79,0x31,0x8,0xc9,0x42,0xcc,
  0x29,0x66,0x66,0x4e,0x93,0xc,0x73,0x8f,0xd0,0x2,0x1c,0xf1,0xbd,0xbc,0x70,0xe3,
  0xe,0x15,0x9b,0x9,0x74,0xc0,0xaf,0xe3,0x2b,0xbf,0xfd,0x2a,0x3b,0x5e,0x1d,0x90,
  0x97,0x61,0x25,0xe8,0x36,0x32,0x78,0x13,0x70,0x76,0x90,0x28,0x25,0x4b,0xba,0x34,
  0x12,0x48,0xed,0x22,0x13,0xb,0xca,0xf0,0x2e,0x0,0xb2,0x98,0xac,0xea,0x4d,0xcc,
  0xd3,0x43,0xf7,0x7d,0xf,0x1f,0x31,0x84,0x28,0xd8,0x2f,0x40,0xfd,0x1c,0x15,0xc5,
  0x2c,0xc2,0xef,0xba,0xbb,0xa3,0x6,0x30,0x9d,0x26,0x12,0x5d,0x30,0xab,0xe0,0x9a,
  0x14,0x16,0x62,0x1,0x23,0xf3,0x4c,0x8f,0x8e,0x9c,0x28,0x78,0x8d,0x27,0xd2,0xaf,
  0x13,0xcc,0x50,0x7b,0x72,0x25,0xb0,0xa1,0x89,0xa5,0x63,0xd1,0x81,0x8e,0xd0,0xe1,
  0xdc,0x88,0x72,0xfa,0xb6,0x73,0x1f,0x52,0x7d,0x2f,0x92,0x33,0x9,0x2b,0x79,0x7b,
  0x85,0x4e,0x26,0x9f,0xa1,0xb2,0x2f,0xd8,0x5b,0x50,0x27,0x2e,0x36,0x13,0xf5,0x58,
  0x38,0xac,0xed,0x7d,0x21,0xa7,0x99,0x79,0xa3,0xa0,0x14,0x2a,0x2d,0x7d,0x35,0xe3,
  0x28,0x60,0xb7,0x63,0xbe,0x41,0x7,0xf1,0x13,0x20,0x70,0xa1,0xff,0x34,0xfe,0x33,
  0x8d,0xf0,0x8a,0x7e,0xa1,0x18,0xb5,0x2b,0x4f,0xf1,0x34,0x8f,0x37,0xfa,0x20,0x44,
  0xae,0xc5,0xd7,0x8d,0x6d,0x8c,0x31,0x19,0x33,0xfb,0x45,0xb3,0x5f,0xe4,0x9,0xd1,
  0x30,0xc3,0x56,0x73,0xf1,0x98,0x99,0xe3,0xe9,0xf,0x6e,0xf2,0xa6,0x19,0xca,0x39,
  0x18,0xcf,0x31,0x83,0x0,0x6d,0xfa,0xa6,0x9,0xe,0xe6,0x46,0x58,0xce,0x98,0x1e,
  0xc1,0xd3,0x91,0xea,0xc4,0x84,0x4b,0x59,0xc0,0xd4,0xac,0x22,0x26,0x5c,0x7,0x10,
  0x3e,0xd1,0xf0,0xa6,0x5e,0xbf,0x33,0xa0,0x11,0xd,0x7f,0x6a,0x9,0x19,0xac,0xa5,
  0x5e,0x28,0x95,0xe8,0x10,0xfe,0x90,0xa,0x67,0x2,0x1d,0x9f,0xb1,0x24,0x50,0x20,
  0xb2,0xed,0x87,0x23,0xaf,0x94,0xa3,0xae,0x52,0xd4,0x68,0xd,0xaf,0x2c,0x7b,0x2f,
  0x94,0x9b,0x7,0x6b,0x84,0x62,0xf9,0x6a,0x67,0xb7,0x99,0x6f,0x90,0x96,0x5,0x69,
  0x81,0xe0,0xf3,0x8b,0x18,0xe7,0x18,0xc7,0xcd,0x8b,0x7e,0xd0,0xc2,0xa,0x43,0xe9,
  0x58,0xf1,0x99,0x19,0xdb,0x55,0x89,0xcc,0xb5,0x92,0x85,0xb4,0x18,0xe5,0xce,0x37,
  0xe1,0xc0,0x58,0x86,0xf2,0x98,0xd3,0x85,0x64,0xc,0x96,0xfd,0x40,0x1c,0x20,0x41,
  0x93,0xec,0xc6,0xb1,0xa0,0x6d,0x9,0x85,0x25,0x71,0xe0,0xca,0x8a,0x65,0x5b,0x44,
  0xaa,0x5e,0xb,0x4a,0x4c,0xa7,0xbc,0xb5,0x85,0xe4,0xcf,0x2,0xa4,0x1d,0x5,0x9a,
  0x40,0x6c,0x85,0xdb,0xf2,0x6d,0x5,0x35,0xc3,0x35,0x7e,0xc4,0x2,0xdc,0x92,0x59,
  0xc6,0x60,0x9a,0xa8,0x84,0xdc,0x53,0xf8,0x53,0x41,0xd8,0xb1,0xe2,0x33,0xf9,0xac,
  0xfb,0xa2,0xd2,0x9c,0xb7,0x6f,0x52,0x6a,0x1,0x4d,0xaf,0x79,0x19,0x53,0x4e,0x22,
  0xe6,0xc,0x25,0x58,0xbe,0xb,0xf4,0xbd,0x21,0xe3,0xbc,0x9e,0xae,0x7f,0xb8,0x91,
  0x7d,0xd5,0x5b,0xbb,0x12,0xec,0x90,0xc6,0x92,0x22,0x6f,0x69,0xa8,0x4f,0x21,0x76,
  0x2e,0x9b,0x1,0x1a,0xba,0xcb,0x13,0x82,0xf4,0x33,0xc1,0x6a,0x9e,0x78,0x2c,0x38,
  0x67,0x50,0xc0,0x8,0x6a,0x36,0xd9,0x99,0x41,0x8c,0x5f,0x85,0x3,0x71,0xfa,0x1f,
  0x67,0xf,0x60,0x55,
  
};

static const unsigned char qt_resource_name[] = {
  // qt
  0x0,0x2,
  0x0,0x0,0x7,0x84,
  0x0,0x71,
  0x0,0x74,
    // qml
  0x0,0x3,
  0x0,0x0,0x78,0x3c,
  0x0,0x71,
  0x0,0x6d,0x0,0x6c,
    // VLC
  0x0,0x3,
  0x0,0x0,0x5b,0x3,
  0x0,0x56,
  0x0,0x4c,0x0,0x43,
    // Widgets
  0x0,0x7,
  0xd,0xfa,0xdc,0x13,
  0x0,0x57,
  0x0,0x69,0x0,0x64,0x0,0x67,0x0,0x65,0x0,0x74,0x0,0x73,
    // qmldir
  0x0,0x6,
  0x7,0x84,0x2b,0x2,
  0x0,0x71,
  0x0,0x6d,0x0,0x6c,0x0,0x64,0x0,0x69,0x0,0x72,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x1,0x9c,0x6,0x48,0x79,0xb8,
  // :/qt
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x1,0x9c,0x6,0x48,0x79,0xb8,
  // :/qt/qml
  0x0,0x0,0x0,0xa,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x3,
0x0,0x0,0x1,0x9c,0x6,0x48,0x79,0xb8,
  // :/qt/qml/VLC
  0x0,0x0,0x0,0x16,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x4,
0x0,0x0,0x1,0x9c,0x6,0x48,0x79,0xb8,
  // :/qt/qml/VLC/Widgets
  0x0,0x0,0x0,0x22,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x5,
0x0,0x0,0x1,0x9c,0x6,0x48,0x79,0xb8,
  // :/qt/qml/VLC/Widgets/qmldir
  0x0,0x0,0x0,0x36,0x0,0x4,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x9c,0x6,0x48,0x79,0xb8,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#if defined(QT_INLINE_NAMESPACE)
inline namespace QT_NAMESPACE {
#elif defined(QT_NAMESPACE)
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#if defined(__ELF__) || defined(__APPLE__)
static inline unsigned char qResourceFeatureZstd()
{
    extern const unsigned char qt_resourceFeatureZstd;
    return qt_resourceFeatureZstd;
}
#else
unsigned char qResourceFeatureZstd();
#endif

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_widgets_assets)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_widgets_assets)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_widgets_assets)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_widgets_assets)()
{
    int version = 3;
    version += QT_RCC_PREPEND_NAMESPACE(qResourceFeatureZstd());
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

#ifdef __clang__
#   pragma clang diagnostic push
#   pragma clang diagnostic ignored "-Wexit-time-destructors"
#endif

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_widgets_assets)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_widgets_assets)(); }
   } dummy;
}

#ifdef __clang__
#   pragma clang diagnostic pop
#endif
